@@ -11,7 +11,7 @@ extern "C" {
 #include <stdint.h>
 
 // Calculate relative address for X86-64, given cs_insn structure
-#define X86_REL_ADDR(insn) (insn.addr + insn.size + insn.x86.disp)
+#define X86_REL_ADDR(insn) (insn.address + insn.size + insn.detail->x86.disp)
 
 //> X86 registers
 typedef enum x86_reg {
@@ -90,8 +90,8 @@ typedef struct cs_x86_op {
 		x86_op_type type;	// operand type
 		union {
 			unsigned int reg;	// register value for REG operand
-			int64_t imm;		// immediate value for C-IMM, P-IMM or IMM operand
-			double fp;			// floating point value for FP operand
+			int64_t imm;		// immediate value for IMM operand
+			double fp;		// floating point value for FP operand
 			x86_op_mem mem;		// base/index/scale/disp value for MEM operand
 		};
 } cs_x86_op;
@@ -208,7 +208,6 @@ typedef enum  x86_insn {
 	X86_INS_BTS,
 	X86_INS_BZHI,
 	X86_INS_CALL,
-	X86_INS_CALLW,
 	X86_INS_CBW,
 	X86_INS_CDQ,
 	X86_INS_CDQE,
@@ -339,14 +338,15 @@ typedef enum  x86_insn {
 	X86_INS_FRSTOR,
 	X86_INS_FNSAVE,
 	X86_INS_FSCALE,
+	X86_INS_FSETPM,
 	X86_INS_FSINCOS,
 	X86_INS_FNSTENV,
 	X86_INS_FS,
 	X86_INS_FXAM,
 	X86_INS_FXRSTOR,
-	X86_INS_FXRSTORQ,
+	X86_INS_FXRSTOR64,
 	X86_INS_FXSAVE,
-	X86_INS_FXSAVEQ,
+	X86_INS_FXSAVE64,
 	X86_INS_FXTRACT,
 	X86_INS_FYL2X,
 	X86_INS_FYL2XP1,
@@ -358,6 +358,7 @@ typedef enum  x86_insn {
 	X86_INS_VMOVAPS,
 	X86_INS_XORPD,
 	X86_INS_XORPS,
+	X86_INS_GETSEC,
 	X86_INS_GS,
 	X86_INS_HADDPD,
 	X86_INS_HADDPS,
@@ -367,12 +368,15 @@ typedef enum  x86_insn {
 	X86_INS_IDIV,
 	X86_INS_FILD,
 	X86_INS_IMUL,
-	X86_INS_INS,
+	X86_INS_INSW,
 	X86_INS_IN,
+	X86_INS_INSD,
+	X86_INS_INSB,
 	X86_INS_INC,
 	X86_INS_INSERTPS,
 	X86_INS_INSERTQ,
 	X86_INS_INT,
+	X86_INS_INT1,
 	X86_INS_INT3,
 	X86_INS_INTO,
 	X86_INS_INVD,
@@ -416,7 +420,6 @@ typedef enum  x86_insn {
 	X86_INS_JLE,
 	X86_INS_JL,
 	X86_INS_JMP,
-	X86_INS_JMPQ,
 	X86_INS_JNE,
 	X86_INS_JNO,
 	X86_INS_JNP,
@@ -425,7 +428,6 @@ typedef enum  x86_insn {
 	X86_INS_JP,
 	X86_INS_JRCXZ,
 	X86_INS_JS,
-	X86_INS_KADDW,
 	X86_INS_KANDNW,
 	X86_INS_KANDW,
 	X86_INS_KMOVW,
@@ -434,7 +436,6 @@ typedef enum  x86_insn {
 	X86_INS_KORW,
 	X86_INS_KSHIFTLW,
 	X86_INS_KSHIFTRW,
-	X86_INS_KTESTW,
 	X86_INS_KUNPCKBW,
 	X86_INS_KXNORW,
 	X86_INS_KXORW,
@@ -468,6 +469,7 @@ typedef enum  x86_insn {
 	X86_INS_LOOPE,
 	X86_INS_LOOPNE,
 	X86_INS_RETF,
+	X86_INS_RETFQ,
 	X86_INS_LSL,
 	X86_INS_LSS,
 	X86_INS_LTR,
@@ -690,7 +692,8 @@ typedef enum  x86_insn {
 	X86_INS_PMULHRW,
 	X86_INS_PMULLD,
 	X86_INS_POP,
-	X86_INS_POPA,
+	X86_INS_POPAW,
+	X86_INS_POPAL,
 	X86_INS_POPCNT,
 	X86_INS_POPF,
 	X86_INS_POPFD,
@@ -711,7 +714,8 @@ typedef enum  x86_insn {
 	X86_INS_PUNPCKHQDQ,
 	X86_INS_PUNPCKLQDQ,
 	X86_INS_PUSH,
-	X86_INS_PUSHA,
+	X86_INS_PUSHAW,
+	X86_INS_PUSHAL,
 	X86_INS_PUSHF,
 	X86_INS_PUSHFD,
 	X86_INS_PUSHFQ,
@@ -742,6 +746,7 @@ typedef enum  x86_insn {
 	X86_INS_RSQRTPS,
 	X86_INS_RSQRTSS,
 	X86_INS_SAHF,
+	X86_INS_SALC,
 	X86_INS_SAR,
 	X86_INS_SARX,
 	X86_INS_SBB,
@@ -875,10 +880,12 @@ typedef enum  x86_insn {
 	X86_INS_VCVTPD2DQ,
 	X86_INS_VCVTPD2PSX,
 	X86_INS_VCVTPD2PS,
+	X86_INS_VCVTPD2UDQ,
 	X86_INS_VCVTPH2PS,
 	X86_INS_VCVTPS2DQ,
 	X86_INS_VCVTPS2PD,
 	X86_INS_VCVTPS2PH,
+	X86_INS_VCVTPS2UDQ,
 	X86_INS_VCVTSD2SI,
 	X86_INS_VCVTSD2USI,
 	X86_INS_VCVTSS2SI,
@@ -1147,6 +1154,10 @@ typedef enum  x86_insn {
 	X86_INS_VPERMPD,
 	X86_INS_VPERMPS,
 	X86_INS_VPERMQ,
+	X86_INS_VPERMT2D,
+	X86_INS_VPERMT2PD,
+	X86_INS_VPERMT2PS,
+	X86_INS_VPERMT2Q,
 	X86_INS_VPEXTRB,
 	X86_INS_VPEXTRD,
 	X86_INS_VPEXTRQ,
@@ -1303,6 +1314,8 @@ typedef enum  x86_insn {
 	X86_INS_VPSUBW,
 	X86_INS_VPTESTMD,
 	X86_INS_VPTESTMQ,
+	X86_INS_VPTESTNMD,
+	X86_INS_VPTESTNMQ,
 	X86_INS_VPTEST,
 	X86_INS_VPUNPCKHBW,
 	X86_INS_VPUNPCKHDQ,
@@ -1325,10 +1338,10 @@ typedef enum  x86_insn {
 	X86_INS_VRCP28SS,
 	X86_INS_VRCPPS,
 	X86_INS_VRCPSS,
-	X86_INS_VRNDSCALESD,
-	X86_INS_VRNDSCALESS,
 	X86_INS_VRNDSCALEPD,
 	X86_INS_VRNDSCALEPS,
+	X86_INS_VRNDSCALESD,
+	X86_INS_VRNDSCALESS,
 	X86_INS_VROUNDPD,
 	X86_INS_VROUNDPS,
 	X86_INS_VROUNDSD,
@@ -1350,7 +1363,6 @@ typedef enum  x86_insn {
 	X86_INS_VSHUFPD,
 	X86_INS_VSHUFPS,
 	X86_INS_VSQRTPD,
-	X86_INS_VSQRT,
 	X86_INS_VSQRTPS,
 	X86_INS_VSQRTSD,
 	X86_INS_VSQRTSS,
@@ -1404,6 +1416,7 @@ typedef enum  x86_insn {
 //> Group of X86 instructions
 typedef enum  x86_insn_group {
 	X86_GRP_INVALID = 0,
+
 	X86_GRP_3DNOW,
 	X86_GRP_AES,
 	X86_GRP_ADX,
@@ -1435,6 +1448,8 @@ typedef enum  x86_insn_group {
 	X86_GRP_CDI,
 	X86_GRP_ERI,
 	X86_GRP_TBM,
+	X86_GRP_16BITMODE,
+	X86_GRP_NOT64BITMODE,
 
 	X86_GRP_JUMP,	// all jump instructions (conditional+direct+indirect jumps)
 
